<?php
/**
* @package     Joomla.Plugin
* @subpackage  Ajax.V12
* @author      Robert Went - https://www.robertwent.com
* @copyright   Copyright (c) 2016 Juicybike
* @license     GNU General Public License version 2 or later; see LICENSE.txt
* @version     1.0
*/

// no direct access
defined('_JEXEC') or die;

class plgAjaxV12 extends JPlugin
{

  function onAjaxV12() {

    $input = JFactory::getApplication()->input;
    $product_id 	= $input->get('product_id', '', 'INT');
    $deposit = $input->get('deposit', 0, 'INT');
    $data = $input->get('data', '', 'RAW');

    $ProductGuid = self::productGuid($product_id);

    //Clean the input values
    $filter = JFilterInput::getInstance();
    $data = json_decode(rawurldecode($data));

    $EmailAddress = $filter->clean($data->Customer->EmailAddress, 'STRING');
    $FirstName = $filter->clean($data->Customer->FirstName, 'STRING');
    $LastName = $filter->clean($data->Customer->LastName, 'STRING');
    $AuthenticationKey = $filter->clean($data->Retailer->AuthenticationKey, 'STRING');
    $RetailerGuid = $filter->clean($data->Retailer->RetailerGuid, 'STRING');
    $RetailerId = $filter->clean($data->Retailer->RetailerId, 'STRING');
    $CashPrice = $filter->clean($data->Order->CashPrice, 'FLOAT');
    $vLink = $filter->clean($data->Order->vLink, 'BOOL') ? 1 : 0;
    $DuplicateSalesReferenceMethod = $filter->clean($data->Order->DuplicateSalesReferenceMethod, 'STRING');
    $SalesReference = $filter->clean($data->Order->SalesReference, 'STRING');

    $xml = '<ApplicationRequest xmlns:i="http://www.w3.org/2001/XMLSchema-instance">'."";
    $xml .= "<Customer>";
    $xml .= "<EmailAddress>{$EmailAddress}</EmailAddress>";
    $xml .= "<FirstName>{$FirstName}</FirstName>";
    $xml .= "<LastName>{$LastName}</LastName>";
    $xml .= "</Customer>";
    $xml .= "<Retailer>";
    $xml .= "<AuthenticationKey>{$AuthenticationKey}</AuthenticationKey>";
    $xml .= "<RetailerGuid>{$RetailerGuid}</RetailerGuid>";
    $xml .= "<RetailerId>{$RetailerId}</RetailerId>";
    $xml .= "</Retailer>";
    $xml .= "<Order>";
    $xml .= "<CashPrice>{$CashPrice}</CashPrice>";
    $xml .= "<Deposit>{$deposit}</Deposit>";
    $xml .= "<vLink>{$vLink}</vLink>"; //Sends the user an email when set to true
    $xml .= "<DuplicateSalesReferenceMethod>{$DuplicateSalesReferenceMethod}</DuplicateSalesReferenceMethod>";
    $xml .= "<SalesReference>{$SalesReference}</SalesReference>";
    $xml .= "<ProductGuid>{$ProductGuid}</ProductGuid>";
    $xml .= "<ProductId>{$product_id}</ProductId>";
    $xml .= "<Lines>";
    foreach ($data->Lines as $product) {
      $order_product_name = $filter->clean($product->order_product_name, 'STRING');
      $order_product_total_price = $filter->clean($product->order_product_total_price, 'FLOAT');
      $order_product_quantity = $filter->clean($product->order_product_quantity, 'INT');
      $order_product_code = $filter->clean($product->order_product_code, 'STRING');
      $xml .= "<OrderLine>";
      $xml .= "<Item>{$order_product_name}</Item>";
      $xml .= "<Price>{$order_product_total_price}</Price>";
      $xml .= "<Qty>{$order_product_quantity}</Qty>";
      $xml .= "<SKU>{$order_product_code}</SKU>";
      $xml .= "</OrderLine>";
    }
    $xml .= "</Lines>";
    $xml .= "</Order>";
    $xml .= '</ApplicationRequest>';

    //Send the request and check the reply

    $ret = self::webCall('submit', $xml);
    if( $ret !== false ) {
      if( preg_match('#<ApplicationFormUrl>(.*)</ApplicationFormUrl>#iU', $ret, $form_url) )
      {
        $form_url = html_entity_decode(trim($form_url[1]));

        return array('formUrl' => $form_url);

      }
      return array('noapplication' => true, 'request' => $xml, 'response' => $ret);
    } else {
      return array('requesterror' => true);
    }

  }

  private function webCall($service, $data) {

    $base_url = 'https://apply.v12finance.com/latest/retailerapi/';

    if($service === 'submit') {
      $service_url = 'SubmitApplication';
    } else {
      //This is really just so we can add new services later
      return false;
    }

    $url = $base_url . $service_url;

    $headers = array(
      'Content-Type: text/xml',
      'Accept: application/xml; charset=UTF-8'
    );

    $session = curl_init($url);
    curl_setopt($session, CURLOPT_POST, true);
    curl_setopt($session, CURLOPT_HTTPHEADER, $headers);
    curl_setopt($session, CURLOPT_POSTFIELDS, $data);
    curl_setopt($session, CURLOPT_HEADER, true);
    curl_setopt($session, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($session, CURLOPT_SSL_VERIFYPEER, false);

    $ret = curl_exec($session);
    curl_close($session);

    return $ret;
  }

  private function productGuid($product_id) {
    switch ($product_id) {
      case '27':
      return '244B3E7A-0FFB-41F2-88D5-ADF78B6A3D9E';
      break;

      case '88':
      return '34EE414C-94D8-4CD2-8F62-FC5B8A2D2A7D';
      break;

      case '28':
      return '8E0BD3A9-657F-457C-B488-DBFAB37FAC39';
      break;

      case '46':
      return 'C3114266-125A-4EA1-AB10-CFB3EBD48B81';
      break;

      case '29':
      return '9D6FA148-EEB2-4345-B5C6-961902A8F0EB';
      break;

      case '30':
      return 'E931AB43-B8AE-431D-AC50-812D413FB5BB';
      break;

      case '146':
      return 'AEDA558E-5406-4CF3-B05C-39EB57B19E37';
      break;

      case '147':
      return '5FDC06BB-ED0B-4365-9ECA-3B4C6C489DD6';
      break;

      case '118':
      return 'B30BDB3C-DECA-460F-9A49-6F67642DA395';
      break;

      case '119':
      return 'E35912B4-CB1B-40EF-A4F9-2E14B60901D4';
      break;

      case '162':
      return '46AFF7E0-910C-4F4D-8D36-4BC3E2A84DAD';
      break;

      case '54':
      return '152FEA32-BE31-4B73-94D9-F23716C42AAC';
      break;

      case '44':
      return 'CC62BB86-F91B-4A85-97EB-94BB7AC4462F';
      break;

      case '112':
      return 'BED9D208-D9C1-4D8E-A29F-DECB53FD0B22';
      break;

      case '64':
      return '1401BD54-9A22-4CE7-8F7C-61A3EBB93639';
      break;

      case '65':
      return 'BBE76DA6-C60E-4881-83FC-328E415F0A5A';
      break;

      case '66':
      return '3FD9BCDE-BC26-47D2-BD4F-DF453BC6F1A1';
      break;

      default:
      return '';
      break;
    }
  }


}


?>
